containertools.fuse_like_named_contiguous_containers_in_expr
============================================================

.. autofunction:: abjad.tools.containertools.fuse_like_named_contiguous_containers_in_expr.fuse_like_named_contiguous_containers_in_expr
